==> cl-sql_3.1.2.orig.tar.gz: cl-sql-3.1.2/db-postgresql/postgresql-loader.lisp <==
;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          postgresql-loader.sql
;;;; Purpose:       PostgreSQL library loader using UFFI
;;;; Programmer:    Kevin M. Rosenberg
;;;; Date Started:  Feb 2002
;;;;
;;;; $Id: postgresql-loader.lisp 9336 2004-05-13 06:55:48Z kevin $
;;;;
;;;; This file, part of CLSQL, is Copyright (c) 2002 by Kevin M. Rosenberg
;;;;
;;;; CLSQL users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;; *************************************************************************

(in-package #:postgresql)


(defvar *postgresql-supporting-libraries* '("crypt" "c")
  "Used only by CMU. List of library flags needed to be passed to ld to
load the PostgresSQL client library succesfully.  If this differs at your site,
set to the right path before compiling or loading the system.")

(defvar *postgresql-library-loaded* nil
  "T if foreign library was able to be loaded successfully")

(defmethod clsql-sys:database-type-library-loaded ((database-type
						    (eql :postgresql)))
  *postgresql-library-loaded*)
				      
(defmethod clsql-sys:database-type-load-foreign ((database-type
						  (eql :postgresql)))
  (let ((libpath (uffi:find-foreign-library 
		  "libpq"
		  '("/opt/postgresql/lib/" "/usr/local/lib/" 
		    #+64bit "/usr/lib64/"
		    "/usr/lib/" "/postgresql/lib/"
		    "/usr/local/pgsql/lib/" "/usr/lib/pgsql/"
		    "/opt/pgsql/lib/pgsql" "/sw/lib/pgsql/")
		  :drive-letters '("C" "D" "E")
		  #+(or macosx darwin ccl-5.0) :types
		  #+(or macosx darwin ccl-5.0) '("so")
		  )))
    (if	(uffi:load-foreign-library libpath
				   :module "postgresql"
				   :supporting-libraries 
				   *postgresql-supporting-libraries*)
	(setq *postgresql-library-loaded* t)
      (warn "Can't load PostgreSQL client library ~A" libpath))))

(clsql-sys:database-type-load-foreign :postgresql)

==> cl-sql_3.6.3.orig.tar.gz: cl-sql-3.6.3/db-postgresql/postgresql-loader.lisp <==
;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          postgresql-loader.sql
;;;; Purpose:       PostgreSQL library loader using UFFI
;;;; Programmer:    Kevin M. Rosenberg
;;;; Date Started:  Feb 2002
;;;;
;;;; $Id: postgresql-loader.lisp 10575 2005-06-08 19:25:26Z kevin $
;;;;
;;;; This file, part of CLSQL, is Copyright (c) 2002 by Kevin M. Rosenberg
;;;;
;;;; CLSQL users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;; *************************************************************************

(in-package #:postgresql)


(defvar *postgresql-supporting-libraries* '("crypt" "c")
  "Used only by CMU. List of library flags needed to be passed to ld to
load the PostgresSQL client library succesfully.  If this differs at your site,
set to the right path before compiling or loading the system.")

(defvar *postgresql-library-loaded* nil
  "T if foreign library was able to be loaded successfully")

(defmethod clsql-sys:database-type-library-loaded ((database-type
						    (eql :postgresql)))
  *postgresql-library-loaded*)
				      
(defmethod clsql-sys:database-type-load-foreign ((database-type
						  (eql :postgresql)))
  (clsql-uffi:find-and-load-foreign-library "libpq"
                                            :module "postgresql"
                                            :supporting-libraries *postgresql-supporting-libraries*)
  (setq *postgresql-library-loaded* t))

(clsql-sys:database-type-load-foreign :postgresql)
